@@ -130,8 +130,7 @@ ca.ServerAction = function() {
         // XXX packer breaks on following
         // regexp constant, so it must be quoted
         // XXX (not needed in javascript syntax)
-        if (! path.match(RegExp("/\/$/"))) {
-            // this really always happens...
+        if (! path.match(RegExp("/$"))) {
             path += '/';
         }
         url = path + url;
